@@ -1,5 +1,6 @@
 from ehelply_logger.Logger import Logger
 import time
+import asyncio
 
 
 class AbstractTimerService:
@@ -20,13 +21,15 @@ class AbstractTimerService:
         self.logger.debug("Delegating control of this thread to " + self.name + " Service.")
         self.logger.debuggg("This thread will now be 'locked' by the " + self.name + " service.")
         self.logger.debuggg("  * If this is unintended, please start the " + self.name + " Service is a new thread.")
-        self._service()
 
-    def _service(self):
+    async def run(self):
+        await self._service()
+
+    async def _service(self):
         while True:
             self.logger.debugg("Proc'd")
-            self.proc()
-            time.sleep(self.delay_seconds)
+            await self.proc()
+            await asyncio.sleep(self.delay_seconds)
 
-    def proc(self):
+    async def proc(self):
         pass
